@@ -1,5 +1,5 @@
 import PySimpleGUI as sg
-from src.gui.custom_components import header, explanation, question_mark
+from NetLogoDOE.src.gui.custom_components import header, explanation, question_mark
 
 
 class MainScreen:
